/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 1031 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 88 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 199 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 211 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 172 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebview.sip"
#include <qwebview.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qgraphicswebview.sip"
#include <qgraphicswebview.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebinspector.sip"
#include <qwebinspector.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 296 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 307 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 217 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 335 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 222 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 349 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 378 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 232 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtWebKitWidgets[] = {
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'C', 'h', 'o', 'o', 's', 'e', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'F', 'i', 'l', 'e', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'C', 'h', 'o', 'o', 's', 'e', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'F', 'i', 'l', 'e', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'R', 'e', 't', 'u', 'r', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 'P', 'a', 'g', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 'P', 'a', 'g', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'R', 'e', 't', 'u', 'r', 'n', 0,
    's', 't', 'a', 't', 'u', 's', 'B', 'a', 'r', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'T', 'r', 'e', 'a', 't', 'M', 'e', 'd', 'i', 'a', 'l', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'A', 's', 'W', 'o', 'r', 'd', 'B', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'e', 's', 't', 'C', 'a', 'n', 'c', 'e', 'l', 'e', 'd', 0,
    'm', 'e', 'n', 'u', 'B', 'a', 'r', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    't', 'o', 'o', 'l', 'B', 'a', 'r', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'L', 'i', 'n', 'k', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'D', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'F', 'o', 'r', 'm', 'R', 'e', 's', 'u', 'b', 'm', 'i', 't', 't', 'e', 'd', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'Q', 'u', 'o', 't', 'a', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd', 0,
    'j', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'l', 'e', 'a', 'r', 'e', 'd', 0,
    'C', 'h', 'o', 'o', 's', 'e', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'F', 'i', 'l', 'e', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'B', 'a', 'c', 'k', 'O', 'r', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'F', 'o', 'r', 'm', 'S', 'u', 'b', 'm', 'i', 't', 't', 'e', 'd', 0,
    'S', 'e', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'L', 'e', 'f', 't', 'T', 'o', 'R', 'i', 'g', 'h', 't', 0,
    'S', 'e', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'i', 'g', 'h', 't', 'T', 'o', 'L', 'e', 'f', 't', 0,
    'a', 'd', 'd', 'T', 'o', 'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'u', 'a', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 'R', 'e', 'c', 't', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 'F', 'r', 'a', 'm', 'e', 'S', 't', 'a', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'e', 't', 'T', 'i', 'l', 'e', 'd', 'B', 'a', 'c', 'k', 'i', 'n', 'g', 'S', 't', 'o', 'r', 'e', 'F', 'r', 'o', 'z', 'e', 'n', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'L', 'i', 'n', 'k', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', ':', ':', 'V', 'a', 'l', 'u', 'e', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'R', 'e', 't', 'u', 'r', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'i', 's', 'T', 'i', 'l', 'e', 'd', 'B', 'a', 'c', 'k', 'i', 'n', 'g', 'S', 't', 'o', 'r', 'e', 'F', 'r', 'o', 'z', 'e', 'n', 0,
    's', 'h', 'o', 'u', 'l', 'd', 'I', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 'F', 'o', 'r', 'S', 'i', 'z', 'e', 0,
    'F', 'i', 'n', 'd', 'A', 't', 'W', 'o', 'r', 'd', 'B', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 's', 'O', 'n', 'l', 'y', 0,
    'I', 'n', 's', 'e', 'r', 't', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'S', 't', 'o', 'p', 'S', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', 'P', 'a', 'g', 'e', 'R', 'e', 'f', 'r', 'e', 's', 'h', 0,
    'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 'P', 'r', 'e', 'r', 'e', 'n', 'd', 'e', 'r', 0,
    'j', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'C', 'o', 'n', 's', 'o', 'l', 'e', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    's', 'e', 't', 'P', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 0,
    'C', 'o', 'p', 'y', 'I', 'm', 'a', 'g', 'e', 'U', 'r', 'l', 'T', 'o', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'C', 'o', 'p', 'y', 'M', 'e', 'd', 'i', 'a', 'U', 'r', 'l', 'T', 'o', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'F', 'i', 'n', 'd', 'W', 'r', 'a', 'p', 's', 'A', 'r', 'o', 'u', 'n', 'd', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'A', 'l', 'l', 'O', 'c', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', 's', 0,
    'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'G', 'r', 'a', 'n', 't', 'e', 'd', 'B', 'y', 'U', 's', 'e', 'r', 0,
    'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'W', 'e', 'b', 'W', 'i', 'n', 'd', 'o', 'w', 'T', 'y', 'p', 'e', 0,
    'S', 'e', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 'U', 'n', 'l', 'o', 'a', 'd', 'e', 'd', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'a', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'S', 't', 'a', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'e', 't', 'L', 'i', 'n', 'k', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    's', 'w', 'a', 'l', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'D', 'e', 'n', 'i', 'e', 'd', 'B', 'y', 'U', 's', 'e', 'r', 0,
    'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'L', 'a', 'y', 'e', 'r', 0,
    'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'L', 'a', 'y', 'o', 'u', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 0,
    'D', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'L', 'i', 'n', 'k', 's', 0,
    'F', 'i', 'n', 'd', 'B', 'e', 'g', 'i', 'n', 's', 'I', 'n', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'W', 'e', 'b', 'K', 'i', 't', 'W', 'i', 'd', 'g', 'e', 't', 's', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 'D', 'o', 'm', 'a', 'i', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'V', 'i', 'd', 'e', 'o', 'F', 'u', 'l', 'l', 's', 'c', 'r', 'e', 'e', 'n', 0,
    'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 'H', 'i', 'd', 'd', 'e', 'n', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 'Q', 'u', 'o', 't', 'a', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd', 0,
    'e', 'n', 'c', 'l', 'o', 's', 'i', 'n', 'g', 'B', 'l', 'o', 'c', 'k', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 's', 0,
    'C', 'o', 'p', 'y', 'I', 'm', 'a', 'g', 'e', 'T', 'o', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'R', 'e', 'l', 'o', 'a', 'd', 0,
    'O', 'p', 'e', 'n', 'F', 'r', 'a', 'm', 'e', 'I', 'n', 'N', 'e', 'w', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'O', 'p', 'e', 'n', 'I', 'm', 'a', 'g', 'e', 'I', 'n', 'N', 'e', 'w', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'O', 'p', 'e', 'n', 'L', 'i', 'n', 'k', 'I', 'n', 'T', 'h', 'i', 's', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'R', 'e', 'l', 'o', 'a', 'd', 'A', 'n', 'd', 'B', 'y', 'p', 'a', 's', 's', 'C', 'a', 'c', 'h', 'e', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'P', 'a', 'u', 's', 'e', 0,
    'l', 'i', 'n', 'k', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    's', 'e', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 's', 'i', 'z', 'e', 's', 'T', 'o', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 'S', 'e', 'c', 't', 'i', 'o', 'n', 'A', 't', 0,
    'C', 'o', 'p', 'y', 'L', 'i', 'n', 'k', 'T', 'o', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'I', 'm', 'a', 'g', 'e', 'T', 'o', 'D', 'i', 's', 'k', 0,
    'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'M', 'e', 'd', 'i', 'a', 'T', 'o', 'D', 'i', 's', 'k', 0,
    'F', 'i', 'n', 'd', 'C', 'a', 's', 'e', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', 0,
    'I', 'n', 's', 'e', 'r', 't', 'L', 'i', 'n', 'e', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'I', 'n', 's', 'e', 'r', 't', 'U', 'n', 'o', 'r', 'd', 'e', 'r', 'e', 'd', 'L', 'i', 's', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'O', 't', 'h', 'e', 'r', 0,
    'O', 'p', 'e', 'n', 'L', 'i', 'n', 'k', 'I', 'n', 'N', 'e', 'w', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'W', 'e', 'b', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'M', 'e', 'd', 'i', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 's', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'S', 't', 'r', 'i', 'k', 'e', 't', 'h', 'r', 'o', 'u', 'g', 'h', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'L', 'i', 'n', 'k', 'T', 'o', 'D', 'i', 's', 'k', 0,
    'E', 'r', 'r', 'o', 'r', 'P', 'a', 'g', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'P', 'a', 's', 't', 'e', 'A', 'n', 'd', 'M', 'a', 't', 'c', 'h', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'f', 'o', 'c', 'u', 's', 'N', 'e', 'x', 't', 'P', 'r', 'e', 'v', 'C', 'h', 'i', 'l', 'd', 0,
    'g', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'S', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 0,
    's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'd', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'u', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'S', 't', 'a', 'r', 't', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'D', 'o', 'n', 't', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'L', 'i', 'n', 'k', 's', 0,
    'I', 'n', 's', 'e', 'r', 't', 'O', 'r', 'd', 'e', 'r', 'e', 'd', 'L', 'i', 's', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', '*', '>', 0,
    'Q', 'W', 'e', 'b', 'H', 'i', 't', 'T', 'e', 's', 't', 'R', 'e', 's', 'u', 'l', 't', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'S', 'u', 'p', 'e', 'r', 's', 'c', 'r', 'i', 'p', 't', 0,
    'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'h', 'a', 's', 'H', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'i', 's', 'C', 'o', 'n', 't', 'e', 'n', 't', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'C', 'o', 'n', 't', 'e', 'n', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    'j', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'C', 'o', 'n', 'f', 'i', 'r', 'm', 0,
    'm', 'i', 'c', 'r', 'o', 'F', 'o', 'c', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 's', 'T', 'o', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'S', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'S', 'c', 'r', 'o', 'l', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    't', 'r', 'i', 'g', 'g', 'e', 'r', 'P', 'a', 'g', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'D', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'A', 'l', 'l', 'L', 'i', 'n', 'k', 's', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'Q', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'W', 'e', 'b', 'V', 'i', 'e', 'w', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'W', 'e', 'b', 'B', 'r', 'o', 'w', 's', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'c', 'o', 'l', 'l', 'i', 'd', 'e', 's', 'W', 'i', 't', 'h', 'I', 't', 'e', 'm', 0,
    'c', 'o', 'l', 'l', 'i', 'd', 'e', 's', 'W', 'i', 't', 'h', 'P', 'a', 't', 'h', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'f', 'i', 'n', 'd', 'F', 'i', 'r', 's', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    'j', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'P', 'r', 'o', 'm', 'p', 't', 0,
    'p', 'a', 'i', 'n', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 0,
    'r', 'e', 'p', 'a', 'i', 'n', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'E', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    's', 't', 'a', 't', 'u', 's', 'B', 'a', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'E', 'n', 'd', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'S', 'c', 'r', 'i', 'p', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'M', 'e', 'd', 'i', 'a', 'L', 'o', 'o', 'p', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'M', 'e', 'd', 'i', 'a', 'M', 'u', 't', 'e', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'S', 'u', 'b', 's', 'c', 'r', 'i', 'p', 't', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'f', 'i', 'n', 'd', 'A', 'l', 'l', 'E', 'l', 'e', 'm', 'e', 'n', 't', 's', 0,
    'h', 'o', 'v', 'e', 'r', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'o', 'v', 'e', 'r', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'i', 't', 'S', 't', 'y', 'l', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'j', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 'A', 'l', 'e', 'r', 't', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'i', 'n', 'k', 'T', 'a', 'r', 'g', 'e', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'l', 'i', 'n', 'k', 'T', 'i', 't', 'l', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    'u', 's', 'e', 'r', 'A', 'g', 'e', 'n', 't', 'F', 'o', 'r', 'U', 'r', 'l', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'J', 'u', 's', 't', 'i', 'f', 'i', 'e', 'd', 0,
    'I', 'n', 's', 'p', 'e', 'c', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'L', 'a', 'y', 'e', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'W', 'e', 'b', 'M', 'o', 'd', 'a', 'l', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'h', 'i', 't', 'T', 'e', 's', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'h', 'o', 'v', 'e', 'r', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'U', 's', 'e', 'r', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'r', 'i', 'n', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'B', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'T', 'o', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    's', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'A', 'u', 't', 'o', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'L', 'a', 'y', 'e', 'r', 0,
    'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'W', 'e', 'b', 'I', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 0,
    'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'T', 'e', 'x', 't', 0,
    'b', 'y', 't', 'e', 's', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'h', 'a', 'r', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    't', 'r', 'i', 'g', 'g', 'e', 'r', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'F', 'i', 'n', 'd', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    'P', 'a', 'n', 'I', 'c', 'o', 'n', 'L', 'a', 'y', 'e', 'r', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'h', 'a', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'O', 'b', 's', 'c', 'u', 'r', 'e', 'd', 'B', 'y', 0,
    'l', 'o', 'a', 'd', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'l', 'o', 'a', 'd', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'U', 'r', 'l', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'H', 't', 'm', 'l', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    't', 'i', 't', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'G', 'e', 'o', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'N', 'o', 'W', 'e', 'b', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'O', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'i', 'c', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'i', 't', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'l', 'i', 'n', 'k', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'l', 'i', 'n', 'k', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'l', 'i', 'n', 'k', 'H', 'o', 'v', 'e', 'r', 'e', 'd', 0,
    'l', 'o', 'a', 'd', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'p', 'o', 'l', 'i', 's', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'A', 'l', 'i', 'g', 'n', 'R', 'i', 'g', 'h', 't', 0,
    'T', 'o', 'g', 'g', 'l', 'e', 'B', 'o', 'l', 'd', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'o', 'o', 's', 'e', 'F', 'i', 'l', 'e', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'l', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 'a', 'q', 'u', 'e', 'A', 'r', 'e', 'a', 0,
    'p', 'a', 'g', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    's', 'c', 'e', 'n', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'P', 'a', 'l', 'e', 't', 't', 'e', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 't', 'a', 'l', 'B', 'y', 't', 'e', 's', 0,
    'u', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'z', 'o', 'o', 'm', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'A', 'l', 'i', 'g', 'n', 'L', 'e', 'f', 't', 0,
    'A', 'l', 'l', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', 0,
    'Q', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'f', 'r', 'a', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'i', 'n', 'k', 'T', 'i', 't', 'l', 'e', 0,
    'm', 'a', 'i', 'n', 'F', 'r', 'a', 'm', 'e', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'o', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'u', 'n', 'd', 'o', 'S', 't', 'a', 'c', 'k', 0,
    'O', 'p', 'e', 'n', 'L', 'i', 'n', 'k', 0,
    'Q', 'W', 'e', 'b', 'P', 'a', 'g', 'e', 0,
    'Q', 'W', 'e', 'b', 'V', 'i', 'e', 'w', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'f', 'i', 'n', 'd', 'T', 'e', 'x', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'h', 'a', 's', 'F', 'o', 'c', 'u', 's', 0,
    'i', 'm', 'a', 'g', 'e', 'U', 'r', 'l', 0,
    'l', 'i', 'n', 'k', 'T', 'e', 'x', 't', 0,
    'm', 'e', 'd', 'i', 'a', 'U', 'r', 'l', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 0,
    's', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'O', 'u', 't', 'd', 'e', 'n', 't', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'v', 'a', 'n', 'c', 'e', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 0,
    'c', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'e', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 'A', 't', 0,
    'h', 'i', 's', 't', 'o', 'r', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'l', 'i', 'n', 'k', 'U', 'r', 'l', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'p', 'a', 'l', 'e', 't', 't', 'e', 0,
    's', 'e', 't', 'H', 't', 'm', 'l', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 0,
    'I', 'n', 'd', 'e', 'n', 't', 0,
    'W', 'e', 'b', 'K', 'i', 't', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'o', 'm', 'a', 'i', 'n', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'o', 'u', 't', 'p', 'u', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'i', 'x', 'm', 'a', 'p', 0,
    'p', 'r', 'i', 'n', 't', '_', 0,
    'r', 'e', 'l', 'o', 'a', 'd', 0,
    's', 'c', 'r', 'o', 'l', 'l', 0,
    's', 'e', 't', 'U', 'r', 'l', 0,
    't', 'o', 'H', 't', 'm', 'l', 0,
    'w', 'i', 'd', 'g', 'e', 't', 0,
    'P', 'a', 's', 't', 'e', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'r', 'a', 'm', 'e', 0,
    'p', 'a', 'i', 'n', 't', 0,
    'p', 'r', 'i', 'n', 't', 0,
    's', 'h', 'a', 'p', 'e', 0,
    't', 'i', 't', 'l', 'e', 0,
    'B', 'a', 'c', 'k', 0,
    'C', 'o', 'p', 'y', 0,
    'H', 't', 't', 'p', 0,
    'R', 'e', 'd', 'o', 0,
    'S', 't', 'o', 'p', 0,
    'U', 'n', 'd', 'o', 0,
    'b', 'a', 'c', 'k', 0,
    'b', 'o', 'd', 'y', 0,
    'c', 'l', 'i', 'p', 0,
    'i', 'c', 'o', 'n', 0,
    'p', 'a', 'g', 'e', 0,
    's', 'i', 'z', 'e', 0,
    's', 't', 'o', 'p', 0,
    't', 'y', 'p', 'e', 0,
    'v', 'i', 'e', 'w', 0,
    'C', 'u', 't', 0,
    'p', 'o', 's', 0,
    'u', 'r', 'l', 0,
};
#line 106 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qgraphicswebview.sip"
// This is needed by the %ConvertSubClassCode.
#include <QGraphicsWebView>

// This is needed for Qt v5.0.0.
#if defined(B0)
#undef B0
#endif
#line 662 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"

::QWebView* sipVH_QtWebKitWidgets_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPage::WebWindowType a0)
{
    ::QWebView* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QWebPage_WebWindowType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QWebView, &sipRes);

    return sipRes;
}

::QString sipVH_QtWebKitWidgets_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, int a1, const ::QString& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NiN", new ::QString(a0), sipType_QString, SIP_NULLPTR, a1, new ::QString(a2), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebFrame*a0, const ::QString& a1, const ::QString& a2, ::QString*a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DNN", a0, sipType_QWebFrame, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR, new ::QString(a2), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bH4)", &sipRes, sipType_QString, a3);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebFrame*a0, const ::QString& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DN", a0, sipType_QWebFrame, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebFrame*a0, const ::QString& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QWebFrame, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);
}

::QString sipVH_QtWebKitWidgets_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebFrame*a0, const ::QString& a1)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DN", a0, sipType_QWebFrame, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebFrame*a0, const ::QNetworkRequest& a1, ::QWebPage::NavigationType a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DNF", a0, sipType_QWebFrame, SIP_NULLPTR, new ::QNetworkRequest(a1), sipType_QNetworkRequest, SIP_NULLPTR, a2, sipType_QWebPage_NavigationType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QObject* sipVH_QtWebKitWidgets_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QUrl& a1, const ::QStringList& a2, const ::QStringList& a3)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNNN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QUrl(a1), sipType_QUrl, SIP_NULLPTR, new ::QStringList(a2), sipType_QStringList, SIP_NULLPTR, new ::QStringList(a3), sipType_QStringList, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

::QWebPage* sipVH_QtWebKitWidgets_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPage::WebWindowType a0)
{
    ::QWebPage* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QWebPage_WebWindowType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QWebPage, &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPage::Extension a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QWebPage_Extension);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPage::Extension a0, const ::QWebPage::ExtensionOption*a1, ::QWebPage::ExtensionReturn*a2)
{
    bool sipRes = 0;
    int sipIsErr = 0;

#line 224 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
        const sipTypeDef *option_type = sipType_QWebPage_ExtensionOption;
        const sipTypeDef *return_type = sipType_QWebPage_ExtensionReturn;
        
        if (a0 == QWebPage::ChooseMultipleFilesExtension)
        {
            option_type = sipType_QWebPage_ChooseMultipleFilesExtensionOption;
            return_type = sipType_QWebPage_ChooseMultipleFilesExtensionReturn;
        }
        else if (a0 == QWebPage::ErrorPageExtension)
        {
            option_type = sipType_QWebPage_ErrorPageExtensionOption;
            return_type = sipType_QWebPage_ErrorPageExtensionReturn;
        }
        
        PyObject *res_obj = sipCallMethod(&sipIsErr, sipMethod, "FDD",
                a0, sipType_QWebPage_Extension,
                a1, option_type, NULL,
                a2, return_type, NULL);
        
        if (res_obj)
        {
            sipParseResult(&sipIsErr, sipMethod, res_obj, "b", &sipRes);
            Py_DECREF(res_obj);
        }
        else
        {
            sipIsErr = 1;
        }
#line 798 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

void sipVH_QtWebKitWidgets_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPage::WebAction a0, bool a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "Fb", a0, sipType_QWebPage_WebAction, a1);
}

int sipVH_QtWebKitWidgets_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QPaintEngine* sipVH_QtWebKitWidgets_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

::QSize sipVH_QtWebKitWidgets_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

int sipVH_QtWebKitWidgets_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QActionEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QActionEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, long*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bl)", &sipRes, a2);

    return sipRes;
}

::QPainter* sipVH_QtWebKitWidgets_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPainter, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

::QRectF sipVH_QtWebKitWidgets_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DF", const_cast< ::QGraphicsItem *>(a0), sipType_QGraphicsItem, SIP_NULLPTR, a1, sipType_Qt_ItemSelectionMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QPainterPath(a0), sipType_QPainterPath, SIP_NULLPTR, a1, sipType_Qt_ItemSelectionMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKitWidgets_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGraphicsItem*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QGraphicsItem *>(a0), sipType_QGraphicsItem, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QPainterPath sipVH_QtWebKitWidgets_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainterPath sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPainterPath, &sipRes);

    return sipRes;
}

int sipVH_QtWebKitWidgets_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneDragDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneDragDropEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneHoverEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneHoverEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

::QVariant sipVH_QtWebKitWidgets_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::InputMethodQuery a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QVariant sipVH_QtWebKitWidgets_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QGraphicsItem_GraphicsItemChange, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneMouseEvent, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsItem*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QGraphicsItem, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneWheelEvent, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

::QSizeF sipVH_QtWebKitWidgets_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::SizeHint a0, const ::QSizeF& a1)
{
    ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_Qt_SizeHint, new ::QSizeF(a1), sipType_QSizeF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qreal*a0, ::qreal*a1, ::qreal*a2, ::qreal*a3)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(dddd)", a0, a1, a2, a3);
}

void sipVH_QtWebKitWidgets_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDD", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionGraphicsItem *>(a1), sipType_QStyleOptionGraphicsItem, SIP_NULLPTR, a2, sipType_QWidget, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QStyleOption*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QStyleOption, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt::WindowFrameSection sipVH_QtWebKitWidgets_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0)
{
    ::Qt::WindowFrameSection sipRes = ::Qt::NoSection;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_Qt_WindowFrameSection, &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

bool sipVH_QtWebKitWidgets_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtWebKitWidgets_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneMoveEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

void sipVH_QtWebKitWidgets_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGraphicsSceneResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QGraphicsSceneResizeEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtWebKitWidgets_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QWebView(void **);}
static const sipTypeDef *sipSubClass_QWebView(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebview.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QWebInspector, &sipType_QWebInspector, -1, 1},
        {sipName_QWebPage, &sipType_QWebPage, -1, 2},
        {sipName_QWebFrame, &sipType_QWebFrame, -1, 3},
        {sipName_QGraphicsWebView, &sipType_QGraphicsWebView, -1, 4},
        {sipName_QWebView, &sipType_QWebView, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1260 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetscmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QWebPage_FindFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_QWebPage_FindFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::FindFlag a0;
        ::QWebPage::FindFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QWebPage_FindFlag, &a0, sipType_QWebPage_FindFlags, &a1, &a1State))
        {
            ::QWebPage::FindFlags*sipRes;

            sipRes = new ::QWebPage::FindFlags((a0 | *a1));
            sipReleaseType(a1, sipType_QWebPage_FindFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_QWebPage_FindFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QWebPage_FindFlag[] = {
    {(void *)slot_QWebPage_FindFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QWebFrame_RenderLayer___or__(PyObject *, PyObject *);}
static PyObject *slot_QWebFrame_RenderLayer___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebFrame::RenderLayer a0;
        ::QWebFrame::RenderLayers* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QWebFrame_RenderLayer, &a0, sipType_QWebFrame_RenderLayers, &a1, &a1State))
        {
            ::QWebFrame::RenderLayers*sipRes;

            sipRes = new ::QWebFrame::RenderLayers((a0 | *a1));
            sipReleaseType(a1, sipType_QWebFrame_RenderLayers, a1State);

            return sipConvertFromNewType(sipRes, sipType_QWebFrame_RenderLayers, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QWebFrame_RenderLayer[] = {
    {(void *)slot_QWebFrame_RenderLayer___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebFrame__RenderLayer, SIP_NULLPTR, 0}, sipNameNr_RenderLayer, 3, slots_QWebFrame_RenderLayer},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebFrame__ValueOwnership, SIP_NULLPTR, 0}, sipNameNr_ValueOwnership, 3, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__ErrorDomain, SIP_NULLPTR, 0}, sipNameNr_ErrorDomain, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__Extension, SIP_NULLPTR, 0}, sipNameNr_Extension, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__Feature, SIP_NULLPTR, 0}, sipNameNr_Feature, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__FindFlag, SIP_NULLPTR, 0}, sipNameNr_FindFlag, 9, slots_QWebPage_FindFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__LinkDelegationPolicy, SIP_NULLPTR, 0}, sipNameNr_LinkDelegationPolicy, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__NavigationType, SIP_NULLPTR, 0}, sipNameNr_NavigationType, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__PermissionPolicy, SIP_NULLPTR, 0}, sipNameNr_PermissionPolicy, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__VisibilityState, SIP_NULLPTR, 0}, sipNameNr_VisibilityState, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__WebAction, SIP_NULLPTR, 0}, sipNameNr_WebAction, 9, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPage__WebWindowType, SIP_NULLPTR, 0}, sipNameNr_WebWindowType, 9, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtWebKitWidgets[] = {
    &sipTypeDef_QtWebKitWidgets_QGraphicsWebView.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QList_0101QWebFrame.mtd_base,
    &sipTypeDef_QtWebKitWidgets_QMultiMap_0100QString_0100QString.mtd_base,
    &sipTypeDef_QtWebKitWidgets_QWebFrame.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebFrame_RenderLayers.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebHitTestResult.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebInspector.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ChooseMultipleFilesExtensionOption.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ChooseMultipleFilesExtensionReturn.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ErrorPageExtensionOption.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ErrorPageExtensionReturn.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ExtensionOption.ctd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ExtensionReturn.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_FindFlags.ctd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebPage_ViewportAttributes.ctd_base,
    &enumTypes[9].etd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtWebKitWidgets_QWebView.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"Qt::InputMethodQuery"},
    {"Qt::ItemSelectionMode"},
    {"Qt::Orientation"},
    {"Qt::ScrollBarPolicy"},
    {"Qt::SizeHint"},
    {"Qt::WindowFrameSection"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtNetwork. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtNetwork[] = {
    {"QNetworkAccessManager"},
    {"QNetworkAccessManager::Operation"},
    {"QNetworkReply"},
    {"QNetworkRequest"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtGui[] = {
    {"QActionEvent"},
    {"QCloseEvent"},
    {"QContextMenuEvent"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QFocusEvent"},
    {"QHideEvent"},
    {"QIcon"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QPaintDevice"},
    {"QPaintDevice::PaintDeviceMetric"},
    {"QPaintEngine"},
    {"QPaintEvent"},
    {"QPainter"},
    {"QPainter::RenderHint"},
    {"QPainter::RenderHints"},
    {"QPainterPath"},
    {"QPalette"},
    {"QPixmap"},
    {"QRegion"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QTabletEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtWidgets[] = {
    {"QAction"},
    {"QGraphicsItem"},
    {"QGraphicsItem::GraphicsItemChange"},
    {"QGraphicsLayoutItem"},
    {"QGraphicsObject"},
    {"QGraphicsSceneContextMenuEvent"},
    {"QGraphicsSceneDragDropEvent"},
    {"QGraphicsSceneHoverEvent"},
    {"QGraphicsSceneMouseEvent"},
    {"QGraphicsSceneMoveEvent"},
    {"QGraphicsSceneResizeEvent"},
    {"QGraphicsSceneWheelEvent"},
    {"QGraphicsWidget"},
    {"QMenu"},
    {"QStyleOption"},
    {"QStyleOptionGraphicsItem"},
    {"QUndoStack"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtPrintSupport. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtPrintSupport[] = {
    {"QPrinter"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWebKit. */
sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtWebKit[] = {
    {"QWebElement"},
    {"QWebElementCollection"},
    {"QWebHistory"},
    {"QWebHistoryItem"},
    {"QWebPluginFactory"},
    {"QWebSecurityOrigin"},
    {"QWebSettings"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtWebKitWidgets_QtCore, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore, SIP_NULLPTR},
    {"PyQt5.QtNetwork", sipImportedTypes_QtWebKitWidgets_QtNetwork, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtWebKitWidgets_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWidgets", sipImportedTypes_QtWebKitWidgets_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtPrintSupport", sipImportedTypes_QtWebKitWidgets_QtPrintSupport, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWebKit", sipImportedTypes_QtWebKitWidgets_QtWebKit, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QWebView, {4, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtWebKitWidgets = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtWebKitWidgets,
    0,
    sipStrings_QtWebKitWidgets,
    importsTable,
    SIP_NULLPTR,
    29,
    sipExportedTypes_QtWebKitWidgets,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtWebKitWidgets;

sip_qt_metaobject_func sip_QtWebKitWidgets_qt_metaobject;
sip_qt_metacall_func sip_QtWebKitWidgets_qt_metacall;
sip_qt_metacast_func sip_QtWebKitWidgets_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtWebKitWidgets()
#else
PyMODINIT_FUNC PyInit_QtWebKitWidgets()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtWebKitWidgets",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtWebKitWidgets = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtWebKitWidgets == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtWebKitWidgets, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtWebKitWidgets_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtWebKitWidgets_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtWebKitWidgets_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtWebKitWidgets_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtWebKitWidgets, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
